Improve this Doc

# Error: $interpolate:reqarg
Missing required argument for MessageFormat

    Expected one of “plural” or “select” at line {0}, column {1} of text “{2}”

## Description

You must specify the MessageFormat function that you're using right after the comma following the Angular expression. Currently, the supported functions are "plural" and "select" (for gender selections.)

For more information about the MessageFormat syntax in interpolation expressions, please refer to MessageFormat extensions section at Angular i18n MessageFormat